==> SyL-0.15.4.tar.gz: SyL/include/lib/Filesystem/SyL_FilesystemFile.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2008 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2008 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_FilesystemFile.php,v 1.3 2008/01/15 09:19:04 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * ե륷ƥΥե륯饹
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2008 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_FilesystemFile.php,v 1.3 2008/01/15 09:19:04 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_FilesystemFile extends SyL_Filesystem
{
    /**
     * ǥꥹȤ
     *
     * @access public
     * @return array ǥ֥ȡʤ
     */
    function getList()
    {
        trigger_error("[SyL error] Unable to use of this method (" . __CLASS__ . "::" . __FUNCTION__ . ")", E_USER_ERROR);
    }

    /**
     * ե뤬¸ߤ뤫å
     *
     * @access protected
     * @return bool true: ¸ߤ롢false: ¸ߤʤ
     */
    function exists()
    {
        return is_file($this->name);
    }

    /**
     * Ǥɲä
     *
     * @access public
     * @param object ǥ֥
     */
    function add($element)
    {
        trigger_error("[SyL error] Unable to use of this method (" . __CLASS__ . "::" . __FUNCTION__ . ")", E_USER_ERROR);
    }

    /**
     * ե
     *
     * @access public
     * @return bool true: OKfalse: 顼
     */
    function delete()
    {
        return unlink($this->name);
    }
}

?>

==> SyL-0.15.6.tar.gz: SyL/include/lib/Filesystem/SyL_FilesystemFile.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2008 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2008 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_FilesystemFile.php,v 1.4 2008/09/23 09:06:15 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * ե륷ƥΥե륯饹
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2008 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_FilesystemFile.php,v 1.4 2008/09/23 09:06:15 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_FilesystemFile extends SyL_Filesystem
{
    /**
     * ǥ쥯ȥȽ
     *
     * @access public
     * @return bool true: ǥ쥯ȥꡢfalse: ǥ쥯ȥʳ
     */
    function isDir()
    {
        return false;
    }

    /**
     * Ǥ¸ߤ뤫å
     *
     * @static
     * @access public 
     * @param string ե̾
     * @return bool true: ¸ߤ롢false: ¸ߤʤ
     */
    function exists($file)
    {
        return is_file($file);
    }

    /**
     * Ǥ
     *
     * @static
     * @access public 
     * @param string ե̾
     * @return bool true: OKfalse: 顼
     */
    function remove($file)
    {
        return unlink($file);
    }
}

?>
